API Reference
=============

Callbacks
---------

.. currentmodule:: pl_extension.callbacks

.. autosummary::
   :toctree: api
   :nosignatures:
   :template: classtemplate.rst

   LRScheduler
   LinearScalingRule
   Speed
   ModelCheckpoint
   Evaluation


Loggers
-------

.. currentmodule:: pl_extension.loggers

.. autosummary::
   :toctree: api
   :nosignatures:
   :template: classtemplate.rst

   LoggingLogger
   MLFlowLogger


Utilities
-------

.. currentmodule:: pl_extension.utilities

.. autosummary::
   :toctree: api
   :nosignatures:

   rand.time_string
